@@ -8,7 +8,7 @@ class BasicAuthDriver(Driver):
 
     def __init__(self):
         super().__init__()
-        self.users = read(getPath(State.paths['root'] + "/users.json"))
+        self.users = read(getPath(State.paths['root'] + "/app/users.json"))
 
     def isApiAuthenticated(self):
         return False
